<?php

namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes();

// Load the system's routing file first, so that the app and ENVIRONMENT
// can override as needed.
if (file_exists(SYSTEMPATH . 'Config/Routes.php')) {
    require SYSTEMPATH . 'Config/Routes.php';
}

/*
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');
$routes->setDefaultController('Main');
$routes->setDefaultMethod('index');
$routes->setTranslateURIDashes(false);
$routes->set404Override();
$routes->setAutoRoute(false);

/*
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.
$routes->get('/', 'Main::index');

$routes->group('admin', ['filter' => 'checkauth'], function ($routes) {
    $routes->get('/', 'Admin\Main::index', ['as' => 'admin.main']);
    $routes->get('test', 'Admin\Main::test', ['as' => 'admin.main.test']);
});



$routes->get('user/logout', 'User::logout', ['as' => 'user.logout']);
$routes->get('user/register', 'User::register', ['as' => 'user.register']);
$routes->post('user/store', 'User::store', ['as' => 'user.store']);
$routes->match(['get', 'post'], 'user/login', 'User::login', ['as' => 'user.login']);

$routes->match(['get', 'post'], 'test', 'Main::test', ['as' => 'main.test']);
$routes->match(['get', 'post'], 'test2', 'Main::test2', ['as' => 'main.test2']);

$routes->match(['get', 'post'], 'file-upload', 'Main::fileUpload', ['as' => 'main.fileupload']);
$routes->match(['get', 'post'], 'file-upload2', 'Main::fileUpload2', ['as' => 'main.fileupload2']);
$routes->match(['get', 'post'], 'file-upload3', 'Main::fileUpload3', ['as' => 'main.fileupload3']);

$routes->get('blog/create', 'Blog::create', ['as' => 'blog_create']);
$routes->post('blog/store', 'Blog::store');

$routes->get('blog/edit/(:num)', 'Blog::edit/$1', ['as' => 'blog_edit']);
$routes->post('blog/update/(:num)', 'Blog::update/$1', ['as' => 'blog_update']);
$routes->delete('blog/delete/(:num)', 'Blog::delete/$1', ['as' => 'blog_delete']);

$routes->get('blog/(:num)', 'Blog::view/$1');
$routes->get('blog', 'Blog::index', ['as' => 'blog_index']);


/*
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need it to be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (file_exists(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php')) {
    require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
